==> tap-parser-1.1.3.tgz: package/test/fixtures/extra-in-child.js <==
module.exports =
[ [ 'line', 'TAP version 13\n' ],
  [ 'version', '13' ],
  [ 'line', '    # Subtest: test/01c-user-updates.js\n' ],
  [ 'child',
    [ [ 'line', '# Subtest: test/01c-user-updates.js\n' ],
      [ 'comment', '# Subtest: test/01c-user-updates.js\n' ],
      [ 'line', 'TAP version 13\n' ],
      [ 'version', '13' ],
      [ 'line', '    # Subtest: update profile\n' ],
      [ 'child',
        [ [ 'line', '# Subtest: update profile\n' ],
          [ 'comment', '# Subtest: update profile\n' ],
          [ 'line', 'ok 1 - should be equivalent\n' ],
          [ 'line', 'ok 2 - should be equivalent\n' ],
          [ 'assert', { ok: true, id: 1, name: 'should be equivalent' } ],
          [ 'line', '1..2\n' ],
          [ 'assert', { ok: true, id: 2, name: 'should be equivalent' } ],
          [ 'plan', { start: 1, end: 2 } ],
          [ 'complete',
            { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
      [ 'line', '    ok 1 - should be equivalent\n' ],
      [ 'line', '    ok 2 - should be equivalent\n' ],
      [ 'line', '    1..2\n' ],
      [ 'line', 'ok 1 - update profile # time=43.094ms\n' ],
      [ 'line', '    # Subtest: update email\n' ],
      [ 'assert',
        { ok: true, id: 1, time: 43.094, name: 'update profile' } ],
      [ 'child',
        [ [ 'line', '# Subtest: update email\n' ],
          [ 'comment', '# Subtest: update email\n' ],
          [ 'line', 'ok 1 - should be equivalent\n' ],
          [ 'line', '1..1\n' ],
          [ 'assert', { ok: true, id: 1, name: 'should be equivalent' } ],
          [ 'plan', { start: 1, end: 1 } ],
          [ 'complete',
            { ok: true, count: 1, pass: 1, plan: { start: 1, end: 1 } } ] ] ],
      [ 'line', 'null { _id: \'org.couchdb.user:user\',\n' ],
      [ 'extra', 'null { _id: \'org.couchdb.user:user\',\n' ],
      [ 'line', '  _rev: \'21-3d786fbf7428194ca288abe40c50cd0c\',\n' ],
      [ 'extra',
        '  _rev: \'21-3d786fbf7428194ca288abe40c50cd0c\',\n' ],
      [ 'line', '  password_scheme: \'pbkdf2\',\n' ],
      [ 'extra', '  password_scheme: \'pbkdf2\',\n' ],
      [ 'line', '  iterations: 10,\n' ],
      [ 'extra', '  iterations: 10,\n' ],
      [ 'line', '  name: \'user\',\n' ],
      [ 'extra', '  name: \'user\',\n' ],
      [ 'line', '  email: \'new@email.com\',\n' ],
      [ 'extra', '  email: \'new@email.com\',\n' ],
      [ 'line', '  type: \'user\',\n' ],
      [ 'extra', '  type: \'user\',\n' ],
      [ 'line', '  roles: [],\n' ],
      [ 'extra', '  roles: [],\n' ],
      [ 'line', '  date: \'2015-05-07T18:04:07.589Z\',\n' ],
      [ 'extra', '  date: \'2015-05-07T18:04:07.589Z\',\n' ],
      [ 'line',
        '  derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
      [ 'extra',
        '  derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
      [ 'line', '  salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
      [ 'extra', '  salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
      [ 'line', '  github: \'user\',\n' ],
      [ 'extra', '  github: \'user\',\n' ],
      [ 'line', '  homepage: \'http://www.user.com\' }\n' ],
      [ 'extra', '  homepage: \'http://www.user.com\' }\n' ],
      [ 'line', '{ _id: \'org.couchdb.user:user\',\n' ],
      [ 'extra', '{ _id: \'org.couchdb.user:user\',\n' ],
      [ 'line', '  _rev: \'22-97703c62ab1f01ea691d40aa8a756cbf\',\n' ],
      [ 'extra',
        '  _rev: \'22-97703c62ab1f01ea691d40aa8a756cbf\',\n' ],
      [ 'line', '  password_scheme: \'pbkdf2\',\n' ],
      [ 'extra', '  password_scheme: \'pbkdf2\',\n' ],
      [ 'line', '  iterations: 10,\n' ],
      [ 'extra', '  iterations: 10,\n' ],
      [ 'line', '  name: \'user\',\n' ],
      [ 'extra', '  name: \'user\',\n' ],
      [ 'line', '  email: \'new@email.com\',\n' ],
      [ 'extra', '  email: \'new@email.com\',\n' ],
      [ 'line', '  type: \'user\',\n' ],
      [ 'extra', '  type: \'user\',\n' ],
      [ 'line', '  roles: [],\n' ],
      [ 'extra', '  roles: [],\n' ],
      [ 'line', '  date: \'2015-05-07T18:04:07.589Z\',\n' ],
      [ 'extra', '  date: \'2015-05-07T18:04:07.589Z\',\n' ],
      [ 'line',
        '  derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
      [ 'extra',
        '  derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
      [ 'line', '  salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
      [ 'extra', '  salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
      [ 'line', '  github: \'user\',\n' ],
      [ 'extra', '  github: \'user\',\n' ],
      [ 'line', '  homepage: \'http://www.user.com\' }\n' ],
      [ 'extra', '  homepage: \'http://www.user.com\' }\n' ],
      [ 'line', '    ok 1 - should be equivalent\n' ],
      [ 'line', '    1..1\n' ],
      [ 'line', 'ok 2 - update email # time=24.16ms\n' ],
      [ 'line', '1..2\n' ],
      [ 'assert',
        { ok: true, id: 2, time: 24.16, name: 'update email' } ],
      [ 'plan', { start: 1, end: 2 } ],
      [ 'complete',
        { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
  [ 'line', '    TAP version 13\n' ],
  [ 'line', '        # Subtest: update profile\n' ],
  [ 'line', '        ok 1 - should be equivalent\n' ],
  [ 'line', '        ok 2 - should be equivalent\n' ],
  [ 'line', '        1..2\n' ],
  [ 'line', '    ok 1 - update profile # time=43.094ms\n' ],
  [ 'line', '        # Subtest: update email\n' ],
  [ 'line', '    null { _id: \'org.couchdb.user:user\',\n' ],
  [ 'line',
    '      _rev: \'21-3d786fbf7428194ca288abe40c50cd0c\',\n' ],
  [ 'line', '      password_scheme: \'pbkdf2\',\n' ],
  [ 'line', '      iterations: 10,\n' ],
  [ 'line', '      name: \'user\',\n' ],
  [ 'line', '      email: \'new@email.com\',\n' ],
  [ 'line', '      type: \'user\',\n' ],
  [ 'line', '      roles: [],\n' ],
  [ 'line', '      date: \'2015-05-07T18:04:07.589Z\',\n' ],
  [ 'line',
    '      derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
  [ 'line',
    '      salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
  [ 'line', '      github: \'user\',\n' ],
  [ 'line', '      homepage: \'http://www.user.com\' }\n' ],
  [ 'line', '    { _id: \'org.couchdb.user:user\',\n' ],
  [ 'line',
    '      _rev: \'22-97703c62ab1f01ea691d40aa8a756cbf\',\n' ],
  [ 'line', '      password_scheme: \'pbkdf2\',\n' ],
  [ 'line', '      iterations: 10,\n' ],
  [ 'line', '      name: \'user\',\n' ],
  [ 'line', '      email: \'new@email.com\',\n' ],
  [ 'line', '      type: \'user\',\n' ],
  [ 'line', '      roles: [],\n' ],
  [ 'line', '      date: \'2015-05-07T18:04:07.589Z\',\n' ],
  [ 'line',
    '      derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
  [ 'line',
    '      salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
  [ 'line', '      github: \'user\',\n' ],
  [ 'line', '      homepage: \'http://www.user.com\' }\n' ],
  [ 'line', '        ok 1 - should be equivalent\n' ],
  [ 'line', '        1..1\n' ],
  [ 'line', '    ok 2 - update email # time=24.16ms\n' ],
  [ 'line', '    1..2\n' ],
  [ 'line', '    # time=174.236ms\n' ],
  [ 'comment', '    # time=174.236ms\n' ],
  [ 'line', 'ok 1 - test/01c-user-updates.js # time=339.14ms\n' ],
  [ 'line', '1..1\n' ],
  [ 'assert',
    { ok: true,
      id: 1,
      time: 339.14,
      name: 'test/01c-user-updates.js' } ],
  [ 'plan', { start: 1, end: 1 } ],
  [ 'line', '# time=343.487ms\n' ],
  [ 'comment', '# time=343.487ms\n' ],
  [ 'complete',
    { ok: true, count: 1, pass: 1, plan: { start: 1, end: 1 } } ] ]

==> tap-parser-1.1.5.tgz: package/test/fixtures/extra-in-child.js <==
module.exports =
[ [ 'line', 'TAP version 13\n' ],
  [ 'version', '13' ],
  [ 'line', '    # Subtest: test/01c-user-updates.js\n' ],
  [ 'child',
    [ [ 'line', '# Subtest: test/01c-user-updates.js\n' ],
      [ 'comment', '# Subtest: test/01c-user-updates.js\n' ],
      [ 'line', 'TAP version 13\n' ],
      [ 'version', '13' ],
      [ 'line', '    # Subtest: update profile\n' ],
      [ 'child',
        [ [ 'line', '# Subtest: update profile\n' ],
          [ 'comment', '# Subtest: update profile\n' ],
          [ 'line', 'ok 1 - should be equivalent\n' ],
          [ 'line', 'ok 2 - should be equivalent\n' ],
          [ 'assert', { ok: true, id: 1, name: 'should be equivalent' } ],
          [ 'line', '1..2\n' ],
          [ 'assert', { ok: true, id: 2, name: 'should be equivalent' } ],
          [ 'plan', { start: 1, end: 2 } ],
          [ 'complete',
            { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
      [ 'line', '    ok 1 - should be equivalent\n' ],
      [ 'line', '    ok 2 - should be equivalent\n' ],
      [ 'line', '    1..2\n' ],
      [ 'line', 'ok 1 - update profile # time=43.094ms\n' ],
      [ 'line', '    # Subtest: update email\n' ],
      [ 'assert',
        { ok: true, id: 1, time: 43.094, name: 'update profile' } ],
      [ 'child',
        [ [ 'line', '# Subtest: update email\n' ],
          [ 'comment', '# Subtest: update email\n' ],
          [ 'line', 'ok 1 - should be equivalent\n' ],
          [ 'line', '1..1\n' ],
          [ 'assert', { ok: true, id: 1, name: 'should be equivalent' } ],
          [ 'plan', { start: 1, end: 1 } ],
          [ 'complete',
            { ok: true, count: 1, pass: 1, plan: { start: 1, end: 1 } } ] ] ],
      [ 'line', 'null { _id: \'org.couchdb.user:user\',\n' ],
      [ 'extra', 'null { _id: \'org.couchdb.user:user\',\n' ],
      [ 'line', '  _rev: \'21-3d786fbf7428194ca288abe40c50cd0c\',\n' ],
      [ 'extra',
        '  _rev: \'21-3d786fbf7428194ca288abe40c50cd0c\',\n' ],
      [ 'line', '  password_scheme: \'pbkdf2\',\n' ],
      [ 'extra', '  password_scheme: \'pbkdf2\',\n' ],
      [ 'line', '  iterations: 10,\n' ],
      [ 'extra', '  iterations: 10,\n' ],
      [ 'line', '  name: \'user\',\n' ],
      [ 'extra', '  name: \'user\',\n' ],
      [ 'line', '  email: \'new@email.com\',\n' ],
      [ 'extra', '  email: \'new@email.com\',\n' ],
      [ 'line', '  type: \'user\',\n' ],
      [ 'extra', '  type: \'user\',\n' ],
      [ 'line', '  roles: [],\n' ],
      [ 'extra', '  roles: [],\n' ],
      [ 'line', '  date: \'2015-05-07T18:04:07.589Z\',\n' ],
      [ 'extra', '  date: \'2015-05-07T18:04:07.589Z\',\n' ],
      [ 'line',
        '  derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
      [ 'extra',
        '  derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
      [ 'line', '  salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
      [ 'extra', '  salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
      [ 'line', '  github: \'user\',\n' ],
      [ 'extra', '  github: \'user\',\n' ],
      [ 'line', '  homepage: \'http://www.user.com\' }\n' ],
      [ 'extra', '  homepage: \'http://www.user.com\' }\n' ],
      [ 'line', '{ _id: \'org.couchdb.user:user\',\n' ],
      [ 'extra', '{ _id: \'org.couchdb.user:user\',\n' ],
      [ 'line', '  _rev: \'22-97703c62ab1f01ea691d40aa8a756cbf\',\n' ],
      [ 'extra',
        '  _rev: \'22-97703c62ab1f01ea691d40aa8a756cbf\',\n' ],
      [ 'line', '  password_scheme: \'pbkdf2\',\n' ],
      [ 'extra', '  password_scheme: \'pbkdf2\',\n' ],
      [ 'line', '  iterations: 10,\n' ],
      [ 'extra', '  iterations: 10,\n' ],
      [ 'line', '  name: \'user\',\n' ],
      [ 'extra', '  name: \'user\',\n' ],
      [ 'line', '  email: \'new@email.com\',\n' ],
      [ 'extra', '  email: \'new@email.com\',\n' ],
      [ 'line', '  type: \'user\',\n' ],
      [ 'extra', '  type: \'user\',\n' ],
      [ 'line', '  roles: [],\n' ],
      [ 'extra', '  roles: [],\n' ],
      [ 'line', '  date: \'2015-05-07T18:04:07.589Z\',\n' ],
      [ 'extra', '  date: \'2015-05-07T18:04:07.589Z\',\n' ],
      [ 'line',
        '  derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
      [ 'extra',
        '  derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
      [ 'line', '  salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
      [ 'extra', '  salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
      [ 'line', '  github: \'user\',\n' ],
      [ 'extra', '  github: \'user\',\n' ],
      [ 'line', '  homepage: \'http://www.user.com\' }\n' ],
      [ 'extra', '  homepage: \'http://www.user.com\' }\n' ],
      [ 'line', '    ok 1 - should be equivalent\n' ],
      [ 'line', '    1..1\n' ],
      [ 'line', 'ok 2 - update email # time=24.16ms\n' ],
      [ 'line', '1..2\n' ],
      [ 'assert',
        { ok: true, id: 2, time: 24.16, name: 'update email' } ],
      [ 'plan', { start: 1, end: 2 } ],
      [ 'line', '# time=174.236ms\n' ],
      [ 'comment', '# time=174.236ms\n' ],
      [ 'complete',
        { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
  [ 'line', '    TAP version 13\n' ],
  [ 'line', '        # Subtest: update profile\n' ],
  [ 'line', '        ok 1 - should be equivalent\n' ],
  [ 'line', '        ok 2 - should be equivalent\n' ],
  [ 'line', '        1..2\n' ],
  [ 'line', '    ok 1 - update profile # time=43.094ms\n' ],
  [ 'line', '        # Subtest: update email\n' ],
  [ 'line', '    null { _id: \'org.couchdb.user:user\',\n' ],
  [ 'line',
    '      _rev: \'21-3d786fbf7428194ca288abe40c50cd0c\',\n' ],
  [ 'line', '      password_scheme: \'pbkdf2\',\n' ],
  [ 'line', '      iterations: 10,\n' ],
  [ 'line', '      name: \'user\',\n' ],
  [ 'line', '      email: \'new@email.com\',\n' ],
  [ 'line', '      type: \'user\',\n' ],
  [ 'line', '      roles: [],\n' ],
  [ 'line', '      date: \'2015-05-07T18:04:07.589Z\',\n' ],
  [ 'line',
    '      derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
  [ 'line',
    '      salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
  [ 'line', '      github: \'user\',\n' ],
  [ 'line', '      homepage: \'http://www.user.com\' }\n' ],
  [ 'line', '    { _id: \'org.couchdb.user:user\',\n' ],
  [ 'line',
    '      _rev: \'22-97703c62ab1f01ea691d40aa8a756cbf\',\n' ],
  [ 'line', '      password_scheme: \'pbkdf2\',\n' ],
  [ 'line', '      iterations: 10,\n' ],
  [ 'line', '      name: \'user\',\n' ],
  [ 'line', '      email: \'new@email.com\',\n' ],
  [ 'line', '      type: \'user\',\n' ],
  [ 'line', '      roles: [],\n' ],
  [ 'line', '      date: \'2015-05-07T18:04:07.589Z\',\n' ],
  [ 'line',
    '      derived_key: \'efcfbc73438a9d122290e5d0c82d1ca7d0a9ba1f\',\n' ],
  [ 'line',
    '      salt: \'74e7dea17bfe520bb84dd9642f072549\',\n' ],
  [ 'line', '      github: \'user\',\n' ],
  [ 'line', '      homepage: \'http://www.user.com\' }\n' ],
  [ 'line', '        ok 1 - should be equivalent\n' ],
  [ 'line', '        1..1\n' ],
  [ 'line', '    ok 2 - update email # time=24.16ms\n' ],
  [ 'line', '    1..2\n' ],
  [ 'line', '    # time=174.236ms\n' ],
  [ 'line', 'ok 1 - test/01c-user-updates.js # time=339.14ms\n' ],
  [ 'line', '1..1\n' ],
  [ 'assert',
    { ok: true,
      id: 1,
      time: 339.14,
      name: 'test/01c-user-updates.js' } ],
  [ 'plan', { start: 1, end: 1 } ],
  [ 'line', '# time=343.487ms\n' ],
  [ 'comment', '# time=343.487ms\n' ],
  [ 'complete',
    { ok: true, count: 1, pass: 1, plan: { start: 1, end: 1 } } ] ]
